==> ejc-bid-impl-3.0.0-20211126.091124-61-sources.jar: com/ejianc/business/bid/bean/SummaryEntity.java <==
package com.ejianc.business.bid.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;

/**
 *   投标总结 
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_summary")
public class SummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态
    @TableField(value="enroll_id")
    private java.lang.Long enrollId; // 工程id
    @TableField(value="engineering_code")
    private java.lang.String engineeringCode; // 工程编码
    @TableField(value="engineering_name")
    private java.lang.String engineeringName; // 工程名称
    @TableField(value="open_tender_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date openTenderDate; // 开标日期(格式：yyyy-mm-dd)
    @TableField(value="bid_evaluation_id")
    private java.lang.Long bidEvaluationId; // 评标办法id  (自定义档案)
    @TableField(value="bid_evaluation_method")
    private java.lang.String bidEvaluationMethod; // 评标办法  
    @TableField(value="project_leader")
    private java.lang.String projectLeader; // 项目负责人
    @TableField(value="architect")
    private java.lang.String architect; // 建造师
    @TableField(value="bid_result")
    private java.lang.Integer bidResult; // 投标结果 0 已中标 1 未中标
    @TableField(value="bid_winner_id")
    private java.lang.Long bidWinnerId; // 中标单位id
    @TableField(value="bid_winner")
    private java.lang.String bidWinner; // 中标单位
    @TableField(value="bid_opening_place")
    private java.lang.String bidOpeningPlace; // 开标地点
    @TableField(value="win_bidding_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date winBiddingDate; // 中标日期(格式：yyyy-mm-dd)
    @TableField(value="quotation_form")
    private java.lang.Integer quotationForm; // 报价形式 0:总价 1:费率
    @TableField(value="bid_mmy")
    private java.math.BigDecimal bidMmy; // 中标金额  （单位万元）
    @TableField(value="bidding_control_mmy")
    private java.math.BigDecimal biddingControlMmy; // 招标控制价（单位万元）
    @TableField(value="quote_lower_rate")
    private java.math.BigDecimal quoteLowerRate; // 报价下浮率（控制价）% 
    @TableField(value="bid_quotation_rate")
    private java.math.BigDecimal bidQuotationRate; // 投标报价费率 
    @TableField(value="bidding_control_rate")
    private java.math.BigDecimal biddingControlRate; // 招标控制价费率
    @TableField(value="control_quote_lower_rate")
    private java.math.BigDecimal controlQuoteLowerRate; // 报价下浮率（控制价）%
    @TableField(value="duration")
    private java.math.BigDecimal duration; // 工期
    @TableField(value="bid_unit_id")
    private java.lang.Long bidUnitId; // 投标单位id
    @TableField(value="bid_unit")
    private java.lang.String bidUnit; // 投标单位
    @TableField(value="bidding_agent")
    private java.lang.String biddingAgent; // 投标代理人
    @TableField(value="unit_leader_id")
    private java.lang.Long unitLeaderId; // 单位负责人id
    @TableField(value="unit_leader")
    private java.lang.String unitLeader; // 单位负责人
    @TableField(value="quality_target")
    private java.lang.String qualityTarget; // 质量目标
    @TableField(value="bid_section_number")
    private java.lang.Integer bidSectionNumber; // 投标标段数量
    @TableField(value="bid_winning_section")
    private java.lang.String bidWinningSection; // 中标标段
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="notification_status")
    private java.lang.Integer notificationStatus; // 中标通知书返回状态 0 未选择 1 选择
    @TableField(value="bid_winner_news")
    private java.lang.String bidWinnerNews; // 中标单位信息
    @TableField(value="is_bid_winning")
    private java.lang.Integer isBidWinning; // 是否中标





    /**
     * 所属组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程id
     */
    public Long getEnrollId() {
        return enrollId;
    }

    /**
     * 工程id
     */
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }

    /**
     * 工程编码
     */
    public java.lang.String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(java.lang.String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getOpenTenderDate() {
        return openTenderDate;
    }

    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public void setOpenTenderDate(java.util.Date openTenderDate) {
        this.openTenderDate = openTenderDate;
    }
    /**
     * 评标办法id  (自定义档案)
     */
    public java.lang.Long getBidEvaluationId() {
        return bidEvaluationId;
    }

    /**
     * 评标办法id  (自定义档案)
     */
    public void setBidEvaluationId(java.lang.Long bidEvaluationId) {
        this.bidEvaluationId = bidEvaluationId;
    }
    /**
     * 评标办法  
     */
    public java.lang.String getBidEvaluationMethod() {
        return bidEvaluationMethod;
    }

    /**
     * 评标办法  
     */
    public void setBidEvaluationMethod(java.lang.String bidEvaluationMethod) {
        this.bidEvaluationMethod = bidEvaluationMethod;
    }
    /**
     * 项目负责人
     */
    public java.lang.String getProjectLeader() {
        return projectLeader;
    }

    /**
     * 项目负责人
     */
    public void setProjectLeader(java.lang.String projectLeader) {
        this.projectLeader = projectLeader;
    }
    /**
     * 建造师
     */
    public String getArchitect() {
        return architect;
    }
    /**
     * 建造师
     */
    public void setArchitect(String architect) {
        this.architect = architect;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public java.lang.Integer getBidResult() {
        return bidResult;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public void setBidResult(java.lang.Integer bidResult) {
        this.bidResult = bidResult;
    }
    /**
     * 中标单位id
     */
    public java.lang.Long getBidWinnerId() {
        return bidWinnerId;
    }

    /**
     * 中标单位id
     */
    public void setBidWinnerId(java.lang.Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    /**
     * 中标单位
     */
    public java.lang.String getBidWinner() {
        return bidWinner;
    }

    /**
     * 中标单位
     */
    public void setBidWinner(java.lang.String bidWinner) {
        this.bidWinner = bidWinner;
    }
    /**
     * 开标地点
     */
    public java.lang.String getBidOpeningPlace() {
        return bidOpeningPlace;
    }

    /**
     * 开标地点
     */
    public void setBidOpeningPlace(java.lang.String bidOpeningPlace) {
        this.bidOpeningPlace = bidOpeningPlace;
    }
    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getWinBiddingDate() {
        return winBiddingDate;
    }

    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public void setWinBiddingDate(java.util.Date winBiddingDate) {
        this.winBiddingDate = winBiddingDate;
    }
    /**
     * 报价形式 0:总价 1:费率
     */
    public java.lang.Integer getQuotationForm() {
        return quotationForm;
    }

    /**
     * 报价形式 0:总价 1:费率
     */
    public void setQuotationForm(java.lang.Integer quotationForm) {
        this.quotationForm = quotationForm;
    }
    /**
     * 中标金额  （单位万元）
     */
    public java.math.BigDecimal getBidMmy() {
        return bidMmy;
    }

    /**
     * 中标金额  （单位万元）
     */
    public void setBidMmy(java.math.BigDecimal bidMmy) {
        this.bidMmy = bidMmy;
    }
    /**
     * 招标控制价（单位万元）
     */
    public java.math.BigDecimal getBiddingControlMmy() {
        return biddingControlMmy;
    }

    /**
     * 招标控制价（单位万元）
     */
    public void setBiddingControlMmy(java.math.BigDecimal biddingControlMmy) {
        this.biddingControlMmy = biddingControlMmy;
    }
    /**
     * 报价下浮率（控制价）% 
     */
    public java.math.BigDecimal getQuoteLowerRate() {
        return quoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）% 
     */
    public void setQuoteLowerRate(java.math.BigDecimal quoteLowerRate) {
        this.quoteLowerRate = quoteLowerRate;
    }
    /**
     * 投标报价费率 
     */
    public java.math.BigDecimal getBidQuotationRate() {
        return bidQuotationRate;
    }

    /**
     * 投标报价费率 
     */
    public void setBidQuotationRate(java.math.BigDecimal bidQuotationRate) {
        this.bidQuotationRate = bidQuotationRate;
    }
    /**
     * 招标控制价费率
     */
    public java.math.BigDecimal getBiddingControlRate() {
        return biddingControlRate;
    }

    /**
     * 招标控制价费率
     */
    public void setBiddingControlRate(java.math.BigDecimal biddingControlRate) {
        this.biddingControlRate = biddingControlRate;
    }
    /**
     * 报价下浮率（控制价）%
     */
    public java.math.BigDecimal getControlQuoteLowerRate() {
        return controlQuoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）%
     */
    public void setControlQuoteLowerRate(java.math.BigDecimal controlQuoteLowerRate) {
        this.controlQuoteLowerRate = controlQuoteLowerRate;
    }
    /**
     * 工期
     */

    public BigDecimal getDuration() {
        return duration;
    }

    /**
     * 工期
     */
    public void setDuration(BigDecimal duration) {
        this.duration = duration;
    }

    /**
     * 投标单位id
     */
    public java.lang.Long getBidUnitId() {
        return bidUnitId;
    }

    /**
     * 投标单位id
     */
    public void setBidUnitId(java.lang.Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    /**
     * 投标单位
     */
    public java.lang.String getBidUnit() {
        return bidUnit;
    }

    /**
     * 投标单位
     */
    public void setBidUnit(java.lang.String bidUnit) {
        this.bidUnit = bidUnit;
    }
    /**
     * 投标代理人
     */
    public String getBiddingAgent() {
        return biddingAgent;
    }
    /**
     * 投标代理人
     */
    public void setBiddingAgent(String biddingAgent) {
        this.biddingAgent = biddingAgent;
    }

    /**
     * 单位负责人id
     */
    public java.lang.Long getUnitLeaderId() {
        return unitLeaderId;
    }

    /**
     * 单位负责人id
     */
    public void setUnitLeaderId(java.lang.Long unitLeaderId) {
        this.unitLeaderId = unitLeaderId;
    }
    /**
     * 单位负责人
     */
    public java.lang.String getUnitLeader() {
        return unitLeader;
    }

    /**
     * 单位负责人
     */
    public void setUnitLeader(java.lang.String unitLeader) {
        this.unitLeader = unitLeader;
    }
    /**
     * 质量目标
     */
    public java.lang.String getQualityTarget() {
        return qualityTarget;
    }

    /**
     * 质量目标
     */
    public void setQualityTarget(java.lang.String qualityTarget) {
        this.qualityTarget = qualityTarget;
    }
    /**
     * 投标标段数量
     */
    public java.lang.Integer getBidSectionNumber() {
        return bidSectionNumber;
    }

    /**
     * 投标标段数量
     */
    public void setBidSectionNumber(java.lang.Integer bidSectionNumber) {
        this.bidSectionNumber = bidSectionNumber;
    }
    /**
     * 中标标段
     */

    public String getBidWinningSection() {
        return bidWinningSection;
    }

    /**
     * 中标标段
     */
    public void setBidWinningSection(String bidWinningSection) {
        this.bidWinningSection = bidWinningSection;
    }

    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public java.lang.Integer getNotificationStatus() {
        return notificationStatus;
    }

    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public void setNotificationStatus(java.lang.Integer notificationStatus) {
        this.notificationStatus = notificationStatus;
    }
    /**
     * 中标单位信息
     */
    public java.lang.String getBidWinnerNews() {
        return bidWinnerNews;
    }

    /**
     * 中标单位信息
     */
    public void setBidWinnerNews(java.lang.String bidWinnerNews) {
        this.bidWinnerNews = bidWinnerNews;
    }
    /**
     * 是否中标
     */
    public java.lang.Integer getIsBidWinning() {
        return isBidWinning;
    }

    /**
     * 是否中标
     */
    public void setIsBidWinning(java.lang.Integer isBidWinning) {
        this.isBidWinning = isBidWinning;
    }
}

==> ejc-bid-impl-3.0.0-20220323.110522-179-sources.jar: com/ejianc/business/bid/bean/SummaryEntity.java <==
package com.ejianc.business.bid.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;

/**
 *   投标总结 
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_summary")
public class SummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="org_code")
    private java.lang.String orgCode;
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态
    @TableField(value="enroll_id")
    private java.lang.Long enrollId; // 工程id
    @TableField(value="engineering_code")
    private java.lang.String engineeringCode; // 工程编码
    @TableField(value="engineering_name")
    private java.lang.String engineeringName; // 工程名称
    @TableField(value="open_tender_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date openTenderDate; // 开标日期(格式：yyyy-mm-dd)
    @TableField(value="bid_evaluation_id")
    private java.lang.Long bidEvaluationId; // 评标办法id  (自定义档案)
    @TableField(value="bid_evaluation_method")
    private java.lang.String bidEvaluationMethod; // 评标办法  
    @TableField(value="project_leader")
    private java.lang.String projectLeader; // 项目负责人
    @TableField(value="architect")
    private java.lang.String architect; // 建造师
    @TableField(value="bid_result")
    private java.lang.Integer bidResult; // 投标结果 0 已中标 1 未中标
    @TableField(value="bid_winner_id")
    private java.lang.Long bidWinnerId; // 中标单位id
    @TableField(value="bid_winner")
    private java.lang.String bidWinner; // 中标单位
    @TableField(value="bid_opening_place")
    private java.lang.String bidOpeningPlace; // 开标地点
    @TableField(value="win_bidding_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date winBiddingDate; // 中标日期(格式：yyyy-mm-dd)
    @TableField(value="quotation_form")
    private java.lang.Integer quotationForm; // 报价形式 0:总价 1:费率
    @TableField(value="bid_mmy")
    private java.math.BigDecimal bidMmy; // 中标金额  （单位万元）
    @TableField(value="bidding_control_mmy")
    private java.math.BigDecimal biddingControlMmy; // 招标控制价（单位万元）
    @TableField(value="quote_lower_rate")
    private java.math.BigDecimal quoteLowerRate; // 报价下浮率（控制价）% 
    @TableField(value="bid_quotation_rate")
    private java.math.BigDecimal bidQuotationRate; // 投标报价费率 
    @TableField(value="bidding_control_rate")
    private java.math.BigDecimal biddingControlRate; // 招标控制价费率
    @TableField(value="control_quote_lower_rate")
    private java.math.BigDecimal controlQuoteLowerRate; // 报价下浮率（控制价）%
    @TableField(value="duration")
    private java.math.BigDecimal duration; // 工期
    @TableField(value="bid_unit_id")
    private java.lang.Long bidUnitId; // 投标单位id
    @TableField(value="bid_unit")
    private java.lang.String bidUnit; // 投标单位
    @TableField(value="bidding_agent")
    private java.lang.String biddingAgent; // 投标代理人
    @TableField(value="unit_leader_id")
    private java.lang.Long unitLeaderId; // 单位负责人id
    @TableField(value="unit_leader")
    private java.lang.String unitLeader; // 单位负责人
    @TableField(value="quality_target")
    private java.lang.String qualityTarget; // 质量目标
    @TableField(value="bid_section_number")
    private java.lang.Integer bidSectionNumber; // 投标标段数量
    @TableField(value="bid_winning_section")
    private java.lang.String bidWinningSection; // 中标标段
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="notification_status")
    private java.lang.Integer notificationStatus; // 中标通知书返回状态 0 未选择 1 选择
    @TableField(value="bid_winner_news")
    private java.lang.String bidWinnerNews; // 中标单位信息
    @TableField(value="is_bid_winning")
    private java.lang.Integer isBidWinning; // 是否中标
    @TableField(value="use_flag")
    private java.lang.Integer useFlag; // 项目立项是否使用 1 是 0 否
    @TableField(value="built_constructor_id")
    private Long builtConstructorId; // 建造师id






    /**
     * 所属组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 所属组织编码
     */
    public String getOrgCode() {
        return orgCode;
    }
    /**
     * 所属组织编码
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程id
     */
    public Long getEnrollId() {
        return enrollId;
    }

    /**
     * 工程id
     */
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }

    /**
     * 工程编码
     */
    public java.lang.String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(java.lang.String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getOpenTenderDate() {
        return openTenderDate;
    }

    /**
     * 开标日期(格式：yyyy-mm-dd)
     */
    public void setOpenTenderDate(java.util.Date openTenderDate) {
        this.openTenderDate = openTenderDate;
    }
    /**
     * 评标办法id  (自定义档案)
     */
    public java.lang.Long getBidEvaluationId() {
        return bidEvaluationId;
    }

    /**
     * 评标办法id  (自定义档案)
     */
    public void setBidEvaluationId(java.lang.Long bidEvaluationId) {
        this.bidEvaluationId = bidEvaluationId;
    }
    /**
     * 评标办法  
     */
    public java.lang.String getBidEvaluationMethod() {
        return bidEvaluationMethod;
    }

    /**
     * 评标办法  
     */
    public void setBidEvaluationMethod(java.lang.String bidEvaluationMethod) {
        this.bidEvaluationMethod = bidEvaluationMethod;
    }
    /**
     * 项目负责人
     */
    public java.lang.String getProjectLeader() {
        return projectLeader;
    }

    /**
     * 项目负责人
     */
    public void setProjectLeader(java.lang.String projectLeader) {
        this.projectLeader = projectLeader;
    }
    /**
     * 建造师
     */
    public String getArchitect() {
        return architect;
    }
    /**
     * 建造师
     */
    public void setArchitect(String architect) {
        this.architect = architect;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public java.lang.Integer getBidResult() {
        return bidResult;
    }

    /**
     * 投标结果 0 已中标 1 未中标
     */
    public void setBidResult(java.lang.Integer bidResult) {
        this.bidResult = bidResult;
    }
    /**
     * 中标单位id
     */
    public java.lang.Long getBidWinnerId() {
        return bidWinnerId;
    }

    /**
     * 中标单位id
     */
    public void setBidWinnerId(java.lang.Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    /**
     * 中标单位
     */
    public java.lang.String getBidWinner() {
        return bidWinner;
    }

    /**
     * 中标单位
     */
    public void setBidWinner(java.lang.String bidWinner) {
        this.bidWinner = bidWinner;
    }
    /**
     * 开标地点
     */
    public java.lang.String getBidOpeningPlace() {
        return bidOpeningPlace;
    }

    /**
     * 开标地点
     */
    public void setBidOpeningPlace(java.lang.String bidOpeningPlace) {
        this.bidOpeningPlace = bidOpeningPlace;
    }
    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public java.util.Date getWinBiddingDate() {
        return winBiddingDate;
    }

    /**
     * 中标日期(格式：yyyy-mm-dd)
     */
    public void setWinBiddingDate(java.util.Date winBiddingDate) {
        this.winBiddingDate = winBiddingDate;
    }
    /**
     * 报价形式 0:总价 1:费率
     */
    public java.lang.Integer getQuotationForm() {
        return quotationForm;
    }

    /**
     * 报价形式 0:总价 1:费率
     */
    public void setQuotationForm(java.lang.Integer quotationForm) {
        this.quotationForm = quotationForm;
    }
    /**
     * 中标金额  （单位万元）
     */
    public java.math.BigDecimal getBidMmy() {
        return bidMmy;
    }

    /**
     * 中标金额  （单位万元）
     */
    public void setBidMmy(java.math.BigDecimal bidMmy) {
        this.bidMmy = bidMmy;
    }
    /**
     * 招标控制价（单位万元）
     */
    public java.math.BigDecimal getBiddingControlMmy() {
        return biddingControlMmy;
    }

    /**
     * 招标控制价（单位万元）
     */
    public void setBiddingControlMmy(java.math.BigDecimal biddingControlMmy) {
        this.biddingControlMmy = biddingControlMmy;
    }
    /**
     * 报价下浮率（控制价）% 
     */
    public java.math.BigDecimal getQuoteLowerRate() {
        return quoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）% 
     */
    public void setQuoteLowerRate(java.math.BigDecimal quoteLowerRate) {
        this.quoteLowerRate = quoteLowerRate;
    }
    /**
     * 投标报价费率 
     */
    public java.math.BigDecimal getBidQuotationRate() {
        return bidQuotationRate;
    }

    /**
     * 投标报价费率 
     */
    public void setBidQuotationRate(java.math.BigDecimal bidQuotationRate) {
        this.bidQuotationRate = bidQuotationRate;
    }
    /**
     * 招标控制价费率
     */
    public java.math.BigDecimal getBiddingControlRate() {
        return biddingControlRate;
    }

    /**
     * 招标控制价费率
     */
    public void setBiddingControlRate(java.math.BigDecimal biddingControlRate) {
        this.biddingControlRate = biddingControlRate;
    }
    /**
     * 报价下浮率（控制价）%
     */
    public java.math.BigDecimal getControlQuoteLowerRate() {
        return controlQuoteLowerRate;
    }

    /**
     * 报价下浮率（控制价）%
     */
    public void setControlQuoteLowerRate(java.math.BigDecimal controlQuoteLowerRate) {
        this.controlQuoteLowerRate = controlQuoteLowerRate;
    }
    /**
     * 工期
     */

    public BigDecimal getDuration() {
        return duration;
    }

    /**
     * 工期
     */
    public void setDuration(BigDecimal duration) {
        this.duration = duration;
    }

    /**
     * 投标单位id
     */
    public java.lang.Long getBidUnitId() {
        return bidUnitId;
    }

    /**
     * 投标单位id
     */
    public void setBidUnitId(java.lang.Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    /**
     * 投标单位
     */
    public java.lang.String getBidUnit() {
        return bidUnit;
    }

    /**
     * 投标单位
     */
    public void setBidUnit(java.lang.String bidUnit) {
        this.bidUnit = bidUnit;
    }
    /**
     * 投标代理人
     */
    public String getBiddingAgent() {
        return biddingAgent;
    }
    /**
     * 投标代理人
     */
    public void setBiddingAgent(String biddingAgent) {
        this.biddingAgent = biddingAgent;
    }

    /**
     * 单位负责人id
     */
    public java.lang.Long getUnitLeaderId() {
        return unitLeaderId;
    }

    /**
     * 单位负责人id
     */
    public void setUnitLeaderId(java.lang.Long unitLeaderId) {
        this.unitLeaderId = unitLeaderId;
    }
    /**
     * 单位负责人
     */
    public java.lang.String getUnitLeader() {
        return unitLeader;
    }

    /**
     * 单位负责人
     */
    public void setUnitLeader(java.lang.String unitLeader) {
        this.unitLeader = unitLeader;
    }
    /**
     * 质量目标
     */
    public java.lang.String getQualityTarget() {
        return qualityTarget;
    }

    /**
     * 质量目标
     */
    public void setQualityTarget(java.lang.String qualityTarget) {
        this.qualityTarget = qualityTarget;
    }
    /**
     * 投标标段数量
     */
    public java.lang.Integer getBidSectionNumber() {
        return bidSectionNumber;
    }

    /**
     * 投标标段数量
     */
    public void setBidSectionNumber(java.lang.Integer bidSectionNumber) {
        this.bidSectionNumber = bidSectionNumber;
    }
    /**
     * 中标标段
     */

    public String getBidWinningSection() {
        return bidWinningSection;
    }

    /**
     * 中标标段
     */
    public void setBidWinningSection(String bidWinningSection) {
        this.bidWinningSection = bidWinningSection;
    }

    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public java.lang.Integer getNotificationStatus() {
        return notificationStatus;
    }

    /**
     * 中标通知书返回状态 0 未选择 1 选择
     */
    public void setNotificationStatus(java.lang.Integer notificationStatus) {
        this.notificationStatus = notificationStatus;
    }
    /**
     * 中标单位信息
     */
    public java.lang.String getBidWinnerNews() {
        return bidWinnerNews;
    }

    /**
     * 中标单位信息
     */
    public void setBidWinnerNews(java.lang.String bidWinnerNews) {
        this.bidWinnerNews = bidWinnerNews;
    }
    /**
     * 是否中标
     */
    public java.lang.Integer getIsBidWinning() {
        return isBidWinning;
    }

    /**
     * 是否中标
     */
    public void setIsBidWinning(java.lang.Integer isBidWinning) {
        this.isBidWinning = isBidWinning;
    }
    /**
     * 是否被项目立项使用
     */
    public Integer getUseFlag() {
        return useFlag;
    }
    /**
     * 是否被项目立项使用
     */
    public void setUseFlag(Integer useFlag) {
        this.useFlag = useFlag;
    }
    public Long getBuiltConstructorId() {
        return builtConstructorId;
    }

    public void setBuiltConstructorId(Long builtConstructorId) {
        this.builtConstructorId = builtConstructorId;
    }

}
